# History

-----

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## 0.8.0 - 2022-02-27

***Added:***

- Support newer versions of Hatchling

## 0.7.0 - 2022-02-13

***Added:***

- Bump the minimum supported version of Hatchling

## 0.6.0 - 2022-01-19

***Added:***

- Bump the minimum supported version of Hatchling

***Fixed:***

- Properly ignore artifacts from other runs

## 0.5.0 - 2022-01-12

***Added:***

- Bump the minimum supported version of Hatchling, Mypy, and setuptools

***Fixed:***

- Patch Mypy when building with `pip` to fix access to build requirements

## 0.4 - 2022-01-04

***Added:***

- Support Python 3.7

## 0.3 - 2022-01-02

***Added:***

- Bump the minimum supported version of Hatchling for a fix for projects with a `src`-layout structure

## 0.2 - 2021-12-31

***Added:***

- Default to using the standard file selection options for easier configuration
- Support `src`-layout project structures

## 0.1 - 2021-12-29

This is the initial public release.
